==> qtjambi-qt3danimation-jre8-5.15.3-sources.jar: io/qt/qt3d/animation/QBlendedClipAnimator.java <==
package io.qt.qt3d.animation;


/**
 * <p>Component providing animation playback capabilities of a tree of blend nodes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qblendedclipanimator.html">Qt3DAnimation::QBlendedClipAnimator</a></p>
 */
public class QBlendedClipAnimator extends io.qt.qt3d.animation.QAbstractClipAnimator
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QBlendedClipAnimator.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::blendTreeChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blendTree")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> blendTreeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QBlendedClipAnimator(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QBlendedClipAnimator() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QBlendedClipAnimator(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QBlendedClipAnimator instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::blendTree()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blendTree")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode blendTree(){
        return blendTree_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode blendTree_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::setBlendTree(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blendTree")
    public final void setBlendTree(io.qt.qt3d.animation.QAbstractClipBlendNode blendTree){
        setBlendTree_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(blendTree));
    }
    
    private native void setBlendTree_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long blendTree);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QBlendedClipAnimator(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QBlendedClipAnimator(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QBlendedClipAnimator instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.3.0-sources.jar: io/qt/qt3d/animation/QBlendedClipAnimator.java <==
package io.qt.qt3d.animation;


/**
 * <p>Component providing animation playback capabilities of a tree of blend nodes</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qblendedclipanimator.html">Qt3DAnimation::QBlendedClipAnimator</a></p>
 */
public class QBlendedClipAnimator extends io.qt.qt3d.animation.QAbstractClipAnimator
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QBlendedClipAnimator.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::blendTreeChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blendTree")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> blendTreeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QBlendedClipAnimator(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QBlendedClipAnimator() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QBlendedClipAnimator(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QBlendedClipAnimator instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::blendTree()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blendTree")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode blendTree(){
        return blendTree_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode blendTree_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qblendedclipanimator.html#blendTree-prop">Qt3DAnimation::QBlendedClipAnimator::setBlendTree(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blendTree")
    public final void setBlendTree(io.qt.qt3d.animation.QAbstractClipBlendNode blendTree){
        setBlendTree_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(blendTree));
    }
    
    private native void setBlendTree_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long blendTree);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QBlendedClipAnimator(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QBlendedClipAnimator(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QBlendedClipAnimator instance, QDeclarativeConstructor constructor);
    
}
